.. _contents:
coral Documentation Contents
============================

.. toctree::
   :maxdepth: 3

   tutorial/index
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
